<h1 align="center">ALSHBG</h1>
<p align="center">It is a project that includes all social networking sites, and the most important features of the project is a private library whose work is to verify the availability of the user name if it is available or not available on more than one social site</p>

## Installation :
```
pip install ALSHBG
```
## ***The method of work***
* Open a file in a text editor and name the file eg
ALSHBG.py

For example, we will check the username on Tiktok
```python 
python3 ALSHBG.py 

from ALSHBG import check

ck = check()

BG = ck.Tiktok("username")

print(BG)
```
* If the result is 200, this indicates that your Tiktok username is available☑️

* If the result is 404, this indicates that the Tiktok username is not available ❎

## ***The sites available in the project are***

* Instagram
* Tiktok 
* Snapchat 
* Telegramg 
* Tellonym 
* Twitch 
* Xbox 
* github 
* Reddit 
* Gmail 
* Hotmail 
* Yahoo 
* Steam 
* Sony 
* Like 

## Follow us on social media
[![Telegram](https://img.shields.io/badge/Telegram-ALSH_3k-orange?style=for-the-badge&logo=Telegram)](https://t.me/ALSH_3K)
[![Youtube](https://img.shields.io/badge/Youtube-ALSH-orange?style=for-the-badge&logo=Youtube)](https://youtube.com/channel/UCUNbzQRjfAXGCKI1LY72DTA)
[![Instagram](https://img.shields.io/badge/Instagram-ALSH-green?style=for-the-badge&logo=instagram)](https://Instagram.com/alsh_bg)
[![Telegram](https://img.shields.io/badge/Telegram-ALSH-green?style=for-the-badge&logo=Telegram)](https://t.me/XXCBB)


